==> nrbc-1.3-sources.jar: org/example/drire/RiskandpbduetocrisisResponse.java <==

package org.example.drire;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="gravityCrisis" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "gravityCrisis"
})
@XmlRootElement(name = "riskandpbduetocrisisResponse")
public class RiskandpbduetocrisisResponse {

    @XmlElement(required = true)
    protected String gravityCrisis;

    /**
     * Gets the value of the gravityCrisis property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGravityCrisis() {
        return gravityCrisis;
    }

    /**
     * Sets the value of the gravityCrisis property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGravityCrisis(String value) {
        this.gravityCrisis = value;
    }

}

==> nrbc-1.4-sources.jar: org/example/drire/RiskandpbduetocrisisResponse.java <==

package org.example.drire;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.builder.JAXBToStringBuilder;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="gravityCrisis" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "gravityCrisis"
})
@XmlRootElement(name = "riskandpbduetocrisisResponse")
public class RiskandpbduetocrisisResponse
    implements ToString
{

    @XmlElement(required = true)
    protected String gravityCrisis;

    /**
     * Gets the value of the gravityCrisis property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGravityCrisis() {
        return gravityCrisis;
    }

    /**
     * Sets the value of the gravityCrisis property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGravityCrisis(String value) {
        this.gravityCrisis = value;
    }

    public void toString(ToStringBuilder toStringBuilder) {
        {
            String theGravityCrisis;
            theGravityCrisis = this.getGravityCrisis();
            toStringBuilder.append("gravityCrisis", theGravityCrisis);
        }
    }

    public String toString() {
        final ToStringBuilder toStringBuilder = new JAXBToStringBuilder(this);
        toString(toStringBuilder);
        return toStringBuilder.toString();
    }

}
